# eric7.QScintilla.DocstringGenerator.GoogledocGenerator

Module implementing the docstring generator for the 'googledoc' style.

### Global Attributes

None

### Classes

None

### Functions

generateDoc | Function to generate the docstring line list iaw.

## generateDoc

generateDoc(functionInfo, editor)

Function to generate the docstring line list iaw. Google documentation style.

Note: Text is created with DESCRIPTION placeholders for descriptions and TYPE placeholders for type information

functionInfo (FunctionInfo)
  object containing the function information to base the docstring on
editor (Editor)
  reference to the editor

Return:
  list of docstring lines

Return Type:
  str

Up